==> redux-1.0.11.tgz: package/lib/tests/selectors.test.js <==
'use strict';

var _themeReducer = require('../reducer/themeReducer');

var _selectors = require('../selectors');

describe('selectBsRedux', function () {
  var state = void 0;
  var bsReduxState = void 0;

  beforeEach(function () {
    bsReduxState = _themeReducer.initialState;
    state = {
      'bs.redux': bsReduxState
    };
  });

  describe('selectBsRedux', function () {
    it('should select the bootstrap-styled-redux state', function () {
      expect((0, _selectors.selectBsRedux)(state)).toEqual(state['bs.redux']);
    });

    it('should select the bootstrap-styled-redux state if the store is immutable and have a get method', function () {
      state.get = jest.fn();
      (0, _selectors.selectBsRedux)(state);
      expect(state.get).toHaveBeenCalledWith('bs.redux');
    });

    describe('selectTheme', function () {
      it('should select the theme', function () {
        expect((0, _selectors.selectTheme)(state)).toEqual(bsReduxState.theme);
      });
    });

    describe('selectThemes', function () {
      it('should select the themes', function () {
        expect((0, _selectors.selectThemes)(state)).toEqual(bsReduxState.themes);
      });
    });

    describe('selectValue', function () {
      it('should select the value', function () {
        expect((0, _selectors.selectValue)(state)).toEqual(bsReduxState.theme._name); // eslint-disable-line no-underscore-dangle
      });
    });

    describe('selectValues', function () {
      it('should select the values', function () {
        expect((0, _selectors.selectValues)(state)).toEqual(Object.keys(bsReduxState.themes).map(function (key) {
          return bsReduxState.themes[key]._name;
        })); // eslint-disable-line no-underscore-dangle
      });
    });
  });
});

==> redux-1.1.1.tgz: package/lib/tests/selectors.test.js <==
"use strict";

var _reducer = require("../reducer");

var _selectors = require("../selectors");

var _constants = require("../constants");

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

describe('selectBsRedux', function () {
  var state;
  var bsReduxState;
  beforeEach(function () {
    bsReduxState = _reducer.initialState;
    state = _defineProperty({}, _constants.REDUX_BS_KEY, bsReduxState);
  });
  describe('selectBsRedux', function () {
    it('should select the @bootstrap-styled/redux state', function () {
      expect((0, _selectors.selectBsRedux)(state)).toEqual(state['bs.redux']);
    });
    describe('selectTheme', function () {
      it('should select the theme', function () {
        expect((0, _selectors.selectTheme)(state)).toEqual(bsReduxState.theme);
      });
    });
    describe('selectThemes', function () {
      it('should select the themes', function () {
        expect((0, _selectors.selectThemes)(state)).toEqual(bsReduxState.themes);
      });
    });
    describe('selectValue', function () {
      it('should select the value', function () {
        expect((0, _selectors.selectValue)(state)).toEqual(bsReduxState.theme._name); // eslint-disable-line no-underscore-dangle
      });
    });
    describe('selectValues', function () {
      it('should select the values', function () {
        expect((0, _selectors.selectValues)(state)).toEqual(Object.keys(bsReduxState.themes).map(function (key) {
          return bsReduxState.themes[key]._name;
        })); // eslint-disable-line no-underscore-dangle
      });
    });
  });
});
